==> geeklog-1.6.1-jp-extended-1.0.zip: geeklog-1.6.1-jp-extended-1.0/plugins/staticpages/language/estonian.php <==
<?php

###############################################################################
# estonian.php
# This is the Estonian language file for the Geeklog Static Page plugin
#
# Copyright (C) 2001 Tony Bibbs
# tony@tonybibbs.com
#
# Estonian translation by Artur Rpp <rtr AT planet DOT ee>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

global $LANG32;

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

$LANG_STATIC = array(
    'newpage' => 'Uus leht',
    'adminhome' => 'Admin avaleht',
    'staticpages' => 'Staatilised lehed',
    'staticpageeditor' => 'Staatiliste lehtede toimetaja',
    'writtenby' => 'Kirjutas',
    'date' => 'Uuendatud',
    'title' => 'Tiitel',
    'content' => 'Sisu',
    'hits' => 'Klikke',
    'staticpagelist' => 'Staatiliste lehtede nimekiri',
    'url' => 'URL',
    'edit' => 'Toimeta',
    'lastupdated' => 'Uuendatud',
    'pageformat' => 'Lehe kujundus',
    'leftrightblocks' => 'vasak- ja paremblokid',
    'blankpage' => 'thi leht',
    'noblocks' => 'blokkideta',
    'leftblocks' => 'Vasakblokid',
    'addtomenu' => 'Lisa mensse',
    'label' => 'Silt',
    'nopages' => 'Ssteemis pole veel staatilisi lehti',
    'save' => 'salvesta',
    'preview' => 'eelvaade',
    'delete' => 'kustuta',
    'cancel' => 'thista',
    'access_denied' => 'Ligips tkestatud',
    'access_denied_msg' => 'Sa proovisid ilma vastavate igusteta ligi pseda hele staatiliste lehtede administreerimislehtedest. Pane thele, et kik sellised katsed logitakse.',
    'all_html_allowed' => 'Kogu HTML on lubatud',
    'results' => 'Staatiliste lehtede tulemus',
    'author' => 'Autor',
    'no_title_or_content' => 'Sa pead titma vhemalt <b>tiitli</b> ja <b>sisu</b> vljad.',
    'no_such_page_anon' => 'Palun logi sisse...',
    'no_page_access_msg' => "Phjuseks vib olla, et sa pole veel sisse loginud vi pole veel {$_CONF['site_name']} lehe registreerunud kasutaja. Palun <a href=\"{$_CONF['site_url']}/users.php?mode=new\"> registreeru {$_CONF['site_name']} lehe kasutajaks.</a> Registreerumine annab sulle kik lehe liikme ligipsuigused.",
    'php_msg' => 'PHP: ',
    'php_warn' => 'Hoiatus! Selle valiku sissellitamisel kivitatakse lehel olevad PHP ksud. Kasuta ettevaatusega!',
    'exit_msg' => 'Tagastuse tp',
    'exit_info' => 'Kasuta logimismrkuste jaoks. Tavalise lehe kasutus- ja turvateadete jaoks jta mrge tegemata.',
    'deny_msg' => 'Ligips sellele lehele on tkestatud. Vimalik, et  see leht on kas kustutatud vi mbernimetatud vi pole sul piisavalt igusi.',
    'stats_headline' => 'Staatiliste lehtede top 10',
    'stats_page_title' => 'Lehe tiitel',
    'stats_hits' => 'Klikke',
    'stats_no_hits' => 'Nib, et saidil pole htegi staatilist lehte vi mitte keegi pole neid vaadanud.',
    'id' => 'ID',
    'duplicate_id' => 'Sisestatud staatilise lehe ID on juba kasutuses. Vali teine ID.',
    'instructions' => 'Staatilise lehe toimetamiseks vi kustutamiseks klpsa allpool staatilise lehe juures olevat toimetamisikooni. Staatilise lehe vaatamiseks klpsa selle tiitlil. Uue loomiseks klpsa "Tee uus" lal. Olemasolevast staatilisest lehest koopia tegemiseks klpsa kopeerimisikooni.',
    'centerblock' => 'Keskblokk: ',
    'centerblock_msg' => 'Kui mrgitud, nidatakse seda staatilist lehte indeks lehel keskblokina.',
    'topic' => 'Rubriik: ',
    'position' => 'Asukoht: ',
    'all_topics' => 'Kik',
    'no_topic' => 'Ainult avaleht',
    'position_top' => 'Lehe laservas',
    'position_feat' => 'Peale pealugu',
    'position_bottom' => 'Lehe allservas',
    'position_entire' => 'Kogu leht',
    'head_centerblock' => 'Keskblokk',
    'centerblock_no' => 'Ei',
    'centerblock_top' => 'lal',
    'centerblock_feat' => 'Pealugu',
    'centerblock_bottom' => 'All',
    'centerblock_entire' => 'Kogu',
    'inblock_msg' => 'Blokina:',
    'inblock_info' => 'Paiguta staatiline leht blokki.',
    'title_edit' => 'Toimeta lehte',
    'title_copy' => 'Tee lehest koopia',
    'title_display' => 'Nita leht',
    'select_php_none' => 'ra kivita PHP',
    'select_php_return' => 'kivita PHP (return)',
    'select_php_free' => 'kivita PHP',
    'php_not_activated' => "Staatilistel lehtedel pole PHP kasutamine sisse llitatud. Tpsemat infot palun vaata <a href=\"{$_CONF['site_url']}/docs/english/staticpages.html#php\">dokumentatsioonist.</a>",
    'printable_format' => 'Prinditaval kujul',
    'copy' => 'Koopia',
    'limit_results' => 'Piira tulemused',
    'search' => 'Otsi',
    'submit' => 'Sisesta',
    'no_new_pages' => 'Pole uusi lehti',
    'pages' => 'Lehti'
);

$PLG_staticpages_MESSAGE15 = 'Sinu kommentaar on saadetud lbivaatamiseks. See ilmub lehele prast moderaatorite poolset heakskiitmist.';
$PLG_staticpages_MESSAGE19 = 'Sinu leht on edukalt salvestatud.';
$PLG_staticpages_MESSAGE20 = 'Sinu leht on edukalt kustutatud.';

// Messages for the plugin upgrade
$PLG_staticpages_MESSAGE3001 = 'Plugina uuendamine pole toetatud.';
$PLG_staticpages_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['staticpages'] = array(
    'label' => 'Staatilised lehed',
    'title' => 'Staatiliste lehtede hlestamine'
);

$LANG_confignames['staticpages'] = array(
    'allow_php' => 'Luba PHP?',
    'sort_by' => 'Keskblokkide sorteerimisalus',
    'sort_menu_by' => 'Menelementide sorteerimisalus',
    'delete_pages' => 'Kustuta lehed, omanikuks?',
    'in_block' => 'Paiguta lehed blokki?',
    'show_hits' => 'Nita klikke?',
    'show_date' => 'Nita aega?',
    'filter_html' => 'Filtreeri HTML-i?',
    'censor' => 'Tsenseeri sisu?',
    'default_permissions' => 'Lehe vaikimisi igused',
    'aftersave' => 'Prast lehe salvestamist',
    'atom_max_items' => 'Maks. lehti veebiteenuste limes',
    'meta_tags' => 'Luba Meta sildid',
    'newstaticpagesinterval' => 'Uute staatiliste lehtede aeg',
    'hidenewstaticpages' => 'Peida: Uued staatilised lehed',
    'title_trim_length' => 'Pealkirja krpimise pikkus',
    'includecenterblocks' => 'Kaasa keskploki staatilised lehed',
    'includephp' => 'Kaasa PHP-ga staatilised lehed',
    'includesearch' => 'Luba staatilised lehed otsingus',
    'includesearchcenterblocks' => 'Kaasa keskploki staatilised lehed',
    'includesearchphp' => 'Kaasa PHP-ga staatilised lehed'
);

$LANG_configsubgroups['staticpages'] = array(
    'sg_main' => 'Peaseaded'
);

$LANG_fs['staticpages'] = array(
    'fs_main' => 'Staatiliste  lehtede peaseadistused',
    'fs_whatsnew' => 'Mida uut plokk',
    'fs_search' => 'Otsingu tulemused',
    'fs_permissions' => 'Vaikimisi igused'
);

// Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['staticpages'] = array(
    0 => array('Jah' => 1, 'Ei' => 0),
    1 => array('Jah' => true, 'Ei' => false),
    2 => array('Aeg' => 'date', 'Lehe ID' => 'id', 'Tiitel' => 'title'),
    3 => array('Aeg' => 'date', 'Lehe ID' => 'id', 'Tiitel' => 'title', 'Silt' => 'label'),
    9 => array('Suuna edasi lehele' => 'item', 'Nita loetelu' => 'list', 'Nita avalehte' => 'home', 'Nita admini lehten' => 'admin'),
    12 => array('Pole ligipsu' => 0, 'Ainult loetav' => 2, 'Loetav ja muudetav' => 3)
);

?>

==> geeklog-1.7.1-jp-extended-1.1.zip: geeklog-1.7.1-jp-extended-1.1/plugins/staticpages/language/estonian.php <==
<?php

###############################################################################
# estonian.php
# This is the Estonian language file for the Geeklog Static Page plugin
#
# Copyright (C) 2001 Tony Bibbs
# tony@tonybibbs.com
#
# Estonian translation by Artur Rpp <rtr AT planet DOT ee>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

global $LANG32;

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

$LANG_STATIC = array(
    'newpage' => 'Uus leht',
    'adminhome' => 'Admin avaleht',
    'staticpages' => 'Staatilised lehed',
    'staticpageeditor' => 'Staatiliste lehtede toimetaja',
    'writtenby' => 'Kirjutas',
    'date' => 'Uuendatud',
    'title' => 'Tiitel',
    'page_title' => 'Page Title',
    'content' => 'Sisu',
    'hits' => 'Klikke',
    'staticpagelist' => 'Staatiliste lehtede nimekiri',
    'url' => 'URL',
    'edit' => 'Toimeta',
    'lastupdated' => 'Uuendatud',
    'pageformat' => 'Lehe kujundus',
    'leftrightblocks' => 'vasak- ja paremblokid',
    'blankpage' => 'thi leht',
    'noblocks' => 'blokkideta',
    'leftblocks' => 'Vasakblokid',
    'addtomenu' => 'Lisa mensse',
    'label' => 'Silt',
    'nopages' => 'Ssteemis pole veel staatilisi lehti',
    'save' => 'salvesta',
    'preview' => 'eelvaade',
    'delete' => 'kustuta',
    'cancel' => 'thista',
    'access_denied' => 'Ligips tkestatud',
    'access_denied_msg' => 'Sa proovisid ilma vastavate igusteta ligi pseda hele staatiliste lehtede administreerimislehtedest. Pane thele, et kik sellised katsed logitakse.',
    'all_html_allowed' => 'Kogu HTML on lubatud',
    'results' => 'Staatiliste lehtede tulemus',
    'author' => 'Autor',
    'no_title_or_content' => 'Sa pead titma vhemalt <b>tiitli</b> ja <b>sisu</b> vljad.',
    'no_such_page_anon' => 'Palun logi sisse...',
    'no_page_access_msg' => "Phjuseks vib olla, et sa pole veel sisse loginud vi pole veel {$_CONF['site_name']} lehe registreerunud kasutaja. Palun <a href=\"{$_CONF['site_url']}/users.php?mode=new\"> registreeru {$_CONF['site_name']} lehe kasutajaks.</a> Registreerumine annab sulle kik lehe liikme ligipsuigused.",
    'php_msg' => 'PHP: ',
    'php_warn' => 'Hoiatus! Selle valiku sissellitamisel kivitatakse lehel olevad PHP ksud. Kasuta ettevaatusega!',
    'exit_msg' => 'Tagastuse tp',
    'exit_info' => 'Kasuta logimismrkuste jaoks. Tavalise lehe kasutus- ja turvateadete jaoks jta mrge tegemata.',
    'deny_msg' => 'Ligips sellele lehele on tkestatud. Vimalik, et  see leht on kas kustutatud vi mbernimetatud vi pole sul piisavalt igusi.',
    'stats_headline' => 'Staatiliste lehtede top 10',
    'stats_page_title' => 'Lehe tiitel',
    'stats_hits' => 'Klikke',
    'stats_no_hits' => 'Nib, et saidil pole htegi staatilist lehte vi mitte keegi pole neid vaadanud.',
    'id' => 'ID',
    'duplicate_id' => 'Sisestatud staatilise lehe ID on juba kasutuses. Vali teine ID.',
    'instructions' => 'Staatilise lehe toimetamiseks vi kustutamiseks klpsa allpool staatilise lehe juures olevat toimetamisikooni. Staatilise lehe vaatamiseks klpsa selle tiitlil. Uue loomiseks klpsa "Tee uus" lal. Olemasolevast staatilisest lehest koopia tegemiseks klpsa kopeerimisikooni.',
    'centerblock' => 'Keskblokk: ',
    'centerblock_msg' => 'Kui mrgitud, nidatakse seda staatilist lehte indeks lehel keskblokina.',
    'topic' => 'Rubriik: ',
    'position' => 'Asukoht: ',
    'all_topics' => 'Kik',
    'no_topic' => 'Ainult avaleht',
    'position_top' => 'Lehe laservas',
    'position_feat' => 'Peale pealugu',
    'position_bottom' => 'Lehe allservas',
    'position_entire' => 'Kogu leht',
    'head_centerblock' => 'Keskblokk',
    'centerblock_no' => 'Ei',
    'centerblock_top' => 'lal',
    'centerblock_feat' => 'Pealugu',
    'centerblock_bottom' => 'All',
    'centerblock_entire' => 'Kogu',
    'inblock_msg' => 'Blokina:',
    'inblock_info' => 'Paiguta staatiline leht blokki.',
    'title_edit' => 'Toimeta lehte',
    'title_copy' => 'Tee lehest koopia',
    'title_display' => 'Nita leht',
    'select_php_none' => 'ra kivita PHP',
    'select_php_return' => 'kivita PHP (return)',
    'select_php_free' => 'kivita PHP',
    'php_not_activated' => "Staatilistel lehtedel pole PHP kasutamine sisse llitatud. Tpsemat infot palun vaata <a href=\"{$_CONF['site_url']}/docs/english/staticpages.html#php\">dokumentatsioonist.</a>",
    'printable_format' => 'Prinditaval kujul',
    'copy' => 'Koopia',
    'limit_results' => 'Piira tulemused',
    'search' => 'Otsi',
    'submit' => 'Sisesta',
    'no_new_pages' => 'Pole uusi lehti',
    'pages' => 'Lehti',
    'comments' => 'Comments',
    'template' => 'Template',
    'use_template' => 'Use Template',
    'template_msg' => 'When checked, this Static Page will be marked as a template.',
    'none' => 'None',
    'use_template_msg' => 'If this Static Page is not a template, you can assign it to use a template. If a selection is made then remember that the content of this page must follow the proper XML format.',
    'draft' => 'Draft',
    'draft_yes' => 'Yes',
    'draft_no' => 'No'
);

$PLG_staticpages_MESSAGE15 = 'Sinu kommentaar on saadetud lbivaatamiseks. See ilmub lehele prast moderaatorite poolset heakskiitmist.';
$PLG_staticpages_MESSAGE19 = 'Sinu leht on edukalt salvestatud.';
$PLG_staticpages_MESSAGE20 = 'Sinu leht on edukalt kustutatud.';
$PLG_staticpages_MESSAGE21 = 'This page does not exist yet. To create the page, please fill in the form below. If you are here by mistake, click the Cancel button.';

// Messages for the plugin upgrade
$PLG_staticpages_MESSAGE3001 = 'Plugina uuendamine pole toetatud.';
$PLG_staticpages_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['staticpages'] = array(
    'label' => 'Staatilised lehed',
    'title' => 'Staatiliste lehtede hlestamine'
);

$LANG_confignames['staticpages'] = array(
    'allow_php' => 'Luba PHP?',
    'sort_by' => 'Keskblokkide sorteerimisalus',
    'sort_menu_by' => 'Menelementide sorteerimisalus',
    'sort_list_by' => 'Sort Admin List by',
    'delete_pages' => 'Kustuta lehed, omanikuks?',
    'in_block' => 'Paiguta lehed blokki?',
    'show_hits' => 'Nita klikke?',
    'show_date' => 'Nita aega?',
    'filter_html' => 'Filtreeri HTML-i?',
    'censor' => 'Tsenseeri sisu?',
    'default_permissions' => 'Lehe vaikimisi igused',
    'aftersave' => 'Prast lehe salvestamist',
    'atom_max_items' => 'Maks. lehti veebiteenuste limes',
    'meta_tags' => 'Luba Meta sildid',
    'comment_code' => 'Comment Default',
    'draft_flag' => 'Draft Flag Default',
    'newstaticpagesinterval' => 'Uute staatiliste lehtede aeg',
    'hidenewstaticpages' => 'Peida: Uued staatilised lehed',
    'title_trim_length' => 'Pealkirja krpimise pikkus',
    'includecenterblocks' => 'Kaasa keskploki staatilised lehed',
    'includephp' => 'Kaasa PHP-ga staatilised lehed',
    'includesearch' => 'Luba staatilised lehed otsingus',
    'includesearchcenterblocks' => 'Kaasa keskploki staatilised lehed',
    'includesearchphp' => 'Kaasa PHP-ga staatilised lehed'
);

$LANG_configsubgroups['staticpages'] = array(
    'sg_main' => 'Peaseaded'
);

$LANG_fs['staticpages'] = array(
    'fs_main' => 'Staatiliste  lehtede peaseadistused',
    'fs_whatsnew' => 'Mida uut plokk',
    'fs_search' => 'Otsingu tulemused',
    'fs_permissions' => 'Vaikimisi igused'
);

// Note: entries 0, 1, 9, 12, 17 are the same as in $LANG_configselects['Core']
$LANG_configselects['staticpages'] = array(
    0 => array('Jah' => 1, 'Ei' => 0),
    1 => array('Jah' => true, 'Ei' => false),
    2 => array('Aeg' => 'date', 'Lehe ID' => 'id', 'Tiitel' => 'title'),
    3 => array('Aeg' => 'date', 'Lehe ID' => 'id', 'Tiitel' => 'title', 'Silt' => 'label'),
    4 => array('Date' => 'date', 'Page ID' => 'id', 'Title' => 'title', 'Author' => 'author'),
    5 => array('Hide' => 'hide', 'Show - Use Modified Date' => 'modified', 'Show - Use Created Date' => 'created'),
    9 => array('Suuna edasi lehele' => 'item', 'Nita loetelu' => 'list', 'Nita avalehte' => 'home', 'Nita admini lehten' => 'admin'),
    12 => array('Pole ligipsu' => 0, 'Ainult loetav' => 2, 'Loetav ja muudetav' => 3),
    17 => array('Comments Enabled' => 0, 'Comments Disabled' => -1)
);

?>
